@@ -37,12 +37,6 @@ has _ids => (
     default => sub { return {} },
 );
 
-has _entry_args => (
-    isa => "HashRef",
-    is  => "ro",
-    default => sub { return {} },
-);
-
 sub id_to_object {
     my ( $self, $id ) = @_;
 
@@ -54,19 +48,14 @@ sub id_to_object {
 }
 
 has entries => (
-    traits => ["Hash"],
     isa => "HashRef",
-    reader => "_entries",
+    is  => "ro",
     default  => sub { return {} },
-    handles => {
-        entries => "values",
-        ids     => "keys",
-    },
 );
 
 sub id_to_entry {
     my ( $self, $id ) = @_;
-    $self->_entries->{$id};
+    $self->entries->{$id};
 }
 
 has intrinsic => (
@@ -107,24 +96,22 @@ has options => (
 );
 
 sub insert {
-    my ( $self, $id, $object, @args ) = @_;
+    my ( $self, $id, $object ) = @_;
 
     $self->_objects->{$object} = $id;
     $self->_ids->{$id} = $object;
-    $self->_entry_args->{$id} = \@args if @args;
 }
 
 sub insert_entry {
-    my ( $self, $id, $entry, $object, @args ) = @_;
+    my ( $self, $id, $entry ) = @_;
 
-    $self->_entries->{$id} = $entry;
-    $self->insert($id, $object, @args);
+    $self->entries->{$id} = $entry;
 }
 
 sub compact_entries {
     my $self = shift;
 
-    my ( $entries, $fc, $simple, $options ) = ( $self->_entries, $self->first_class, $self->simple_entries, $self->options );
+    my ( $entries, $fc, $simple, $options ) = ( $self->entries, $self->first_class, $self->simple_entries, $self->options );
 
     # unify non shared simple references
     if ( my @flatten = grep { not $fc->includes($_) } @$simple ) {
@@ -168,8 +155,6 @@ sub compact_data {
         ref && $self->compact_data($_, $flatten) for @$data;
     } elsif ( ref($data) eq 'HASH' ) {
         ref && $self->compact_data($_, $flatten) for values %$data;
-    } elsif ( ref($data) eq 'SCALAR' || ref($data) eq 'REF' ) {
-        $self->compact_data($$data, $flatten);
     } elsif ( ref($data) eq 'KiokuDB::Entry' ) {
         $self->compact_entry($data, $flatten);
     } else {
@@ -182,7 +167,7 @@ sub compact_data {
 sub imply_root {
     my ( $self, @ids ) = @_;
 
-    my $entries = $self->_entries;
+    my $entries = $self->entries;
 
     foreach my $id ( @ids ) {
         my $entry = $entries->{$id} or next;
@@ -191,41 +176,22 @@ sub imply_root {
     }
 }
 
-sub commit {
-    my ( $self, $backend ) = @_;
-
-    $self->insert_to_backend($backend);
-    $self->update_entries( in_storage => 1 );
-}
-
 sub insert_to_backend {
     my ( $self, $backend ) = @_;
 
-    $backend->insert(values %{ $self->_entries });
+    my @insert = values %{ $self->entries };
+
+    $backend->insert(@insert);
+
+    $self->update_entries;
 }
 
 sub update_entries {
-    my ( $self, @shared_args ) = @_;
-
-    my ( $e, $o ) = ( $self->_entries, $self->_ids );
+    my $self = shift;
 
     my $l = $self->live_objects;
-
-    my $args = $self->_entry_args;
-
-    foreach my $id ( keys %$e ) {
-        my ( $object, $entry ) = ( $o->{$id}, $e->{$id} );
-
-        my @args = @{ $args->{$id} || [] }; # FIXME XXX FIXME FIXME XXX BLAH BLAH
-
-        $l->register_entry( $id => $entry, @shared_args );
-
-        unless ( $l->object_to_id($object) ) {
-            $l->register_object( $id => $object, @args );
-        } else {
-            $l->update_object_entry( $object, $entry, @args );
-        }
-    }
+   
+    $l->update_entries( values %{ $self->entries } );
 }
 
 __PACKAGE__->meta->make_immutable;
